@@ -15,7 +15,7 @@ def invoke_process(args, exec_dir=None):
         if exec_dir:
             arg_list['cwd'] = exec_dir
 
-        logging.info(u'[exec] invoke_process args=%r, exec_dir=%r, dry_run=%r', args, exec_dir, dry_run_global)
+        logging.debug(u'[exec] invoke_process args=%r, exec_dir=%r, dry_run=%r', args, exec_dir, dry_run_global)
         returncode = 0
         try:
             output = subprocess.check_output(**arg_list)
@@ -25,6 +25,6 @@ def invoke_process(args, exec_dir=None):
 
         for line in output.splitlines():
             logging.info(u'[exec] %s', line)
-        logging.info(u'[exec] invoke_process complete args=%r, exec_dir=%r, dry_run=%r', args, exec_dir, dry_run_global)
+        logging.debug(u'[exec] invoke_process complete args=%r, exec_dir=%r, dry_run=%r', args, exec_dir, dry_run_global)
 
         return returncode
